@@ -1,9 +1,6 @@
-/* -*- mode: c; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ex: set tabstop=2 softtabstop=2 shiftwidth=2 expandtab: */
-
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2009,2011,2012, Intel Corporation.
+ * Copyright (C) 2009-2013 Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -15,7 +12,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 
+ * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
@@ -58,10 +55,10 @@
 
 /**
  */
-#define END_LINE            '\n'
+#define END_LINE            ('\n')
 
 /**
  */
 #define END_LINE_STR        "\n"
 
-#endif /* _CONFIG_H_INCLUDED_ */
+#endif				/* _CONFIG_H_INCLUDED_ */
