@@ -1,9 +1,6 @@
-/* -*- mode: c; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ex: set tabstop=2 softtabstop=2 shiftwidth=2 expandtab: */
-
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2009,2011,2012, Intel Corporation.
+ * Copyright (C) 2009-2013 Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -15,7 +12,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 
+ * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
@@ -37,7 +34,17 @@ struct block_device;
  *
  * @return 1 if successful, otherwise the function returns 0.
  */
-typedef int (* send_message_t)(struct block_device *device, enum ibpi_pattern ibpi);
+typedef int (*send_message_t) (struct block_device *device,
+			       enum ibpi_pattern ibpi);
+
+/**
+ * @brief Pointer to a flush buffer function.
+ *
+ * @param[in]    device           pointer to a block device
+ *
+ * @return 1 if successful, otherwise the function returns 0.
+ */
+typedef int (*flush_message_t) (struct block_device *device);
 
 /**
  * @brief Describes a block device.
@@ -46,64 +53,74 @@ typedef int (* send_message_t)(struct block_device *device, enum ibpi_pattern ib
  * or partitions on physical block devices.
  */
 struct block_device {
-  /**
-   * Real path in sysfs tree. This means i.e. if /sys/block/sda is symbolic link
-   * then the link will be read and path stored in sysfs_path field. This path
-   * may not exist in sysfs if connection to physical drive is lost. This filed
-   * cannot have NULL pointer assigned.
-   */
-  char *sysfs_path;
+/**
+ * Real path in sysfs tree. This means i.e. if /sys/block/sda is symbolic link
+ * then the link will be read and path stored in sysfs_path field. This path
+ * may not exist in sysfs if connection to physical drive is lost. This filed
+ * cannot have NULL pointer assigned.
+ */
+	char *sysfs_path;
 
-  /**
-   * The pointer to a function which sends a message to driver in order to
-   * control LEDs in an enclosure or DAS system - @see send_message_t for details.
-   * This field cannot have NULL pointer assigned.
-   */
-  send_message_t send_fn;
+/**
+ * The pointer to a function which sends a message to driver in order to
+ * control LEDs in an enclosure or DAS system - @see send_message_t for details.
+ * This field cannot have NULL pointer assigned.
+ */
+	send_message_t send_fn;
 
-  /**
-   * Canonical path to block device where enclosure management fields are located.
-   * This path is always accessible even if the connection to physical device is lost.
-   * In case of AHCI controller it points to SATA phy. In case of SAS this path
-   * points to SES entry associated with the slot in an enclosure. This field cannot
-   * have NULL pointer assign.
-   */
-  char *cntrl_path;
+/**
+ * The pointer to a function which flush buffers filled by send_fn.
+ */
+	flush_message_t flush_fn;
 
-  /**
-   * The current state of block device. This is an IBPI pattern and it is used
-   * to visualize the state of block device.
-   */
-  enum ibpi_pattern ibpi;
+/**
+ * Canonical path to block device where enclosure management fields are located.
+ * This path is always accessible even if the connection to physical device
+ * is lost. In case of AHCI controller it points to SATA phy. In case of SAS
+ * this path points to SES entry associated with the slot in an enclosure.
+ * This field cannot have NULL pointer assign.
+ */
+	char *cntrl_path;
 
-  /**
-   * The time stamp used to determine if the given block device still exist or
-   * it failed and the device is no longer available. Every time IBPI pattern
-   * is updated, the time-stamp is updated, too.
-   */
-  time_t timestamp;
+/**
+ * The current state of block device. This is an IBPI pattern and it is used
+ * to visualize the state of block device.
+ */
+	enum ibpi_pattern ibpi;
 
-  /**
-   * The pointer to storage controller structure the device is connected to.
-   */
-  struct cntrl_device *cntrl;
+/**
+ * The previous state of block device.
+ */
+	enum ibpi_pattern ibpi_prev;
 
-  struct _host_type *host;
+/**
+ * The time stamp used to determine if the given block device still exist or
+ * it failed and the device is no longer available. Every time IBPI pattern
+ * is updated, the time-stamp is updated, too.
+ */
+	time_t timestamp;
 
-  int host_id;
+/**
+ * The pointer to storage controller structure the device is connected to.
+ */
+	struct cntrl_device *cntrl;
 
-	/**
-   * The index of phy utilized by directly attached to controller block device.
-   * It is meaningful if device is controlled by isci driver.
-   */
-  int phy_index;
+	struct _host_type *host;
 
-  /**
-   * The index in Enclosure. This is what should be used when using SES-2.
-   */
-  int encl_index;
+	int host_id;
 
-  char encl_dev[PATH_MAX];
+/**
+ * The index of phy utilized by directly attached to controller block device.
+ * It is meaningful if device is controlled by isci driver.
+ */
+	int phy_index;
+
+/**
+ * The index in Enclosure. This is what should be used when using SES-2.
+ */
+	int encl_index;
+
+	char encl_dev[PATH_MAX];
 };
 
 /**
@@ -121,16 +138,17 @@ struct block_device {
  * @return Pointer to block device structure if successful, otherwise the function
  *         returns the NULL pointer.
  */
-struct block_device * block_device_init(void *cntrl_list, const char *path);
+struct block_device *block_device_init(void *cntrl_list, const char *path);
 
 /**
  * @brief Releases a block device structure.
  *
- * This function releases memory allocated for block device structure. To be more
- * specific it only frees memory allocated for the structure fields. It is due to
- * the way list is implemented for the purpose of this utility. If one would like
- * release block device structure not stored as a list node it must call free()
- * explicitly just after function block_device_fini() is called.
+ * This function releases memory allocated for block device structure.
+ * To be more specific it only frees memory allocated for the structure fields.
+ * It is due to the way list is implemented for the purpose of this utility.
+ * If one would like release block device structure not stored as a list node
+ * it must call free() explicitly just after function block_device_fini()
+ * is called.
  *
  * @param[in]      device         pointer to block device structure.
  *
@@ -151,7 +169,7 @@ void block_device_fini(struct block_device *device);
  * @return Pointer to block device structure if successful, otherwise the function
  *         returns the NULL pointer.
  */
-struct block_device * block_device_duplicate(struct block_device *device);
+struct block_device *block_device_duplicate(struct block_device *device);
 
 /**
  * @brief Determines a storage controller.
@@ -185,4 +203,4 @@ int dev_directly_attached(const char *path);
  */
 struct _host_type *block_get_host(struct cntrl_device *cntrl, int host_id);
 
-#endif /* _BLOCK_H_INCLUDED_ */
+#endif				/* _BLOCK_H_INCLUDED_ */
