@@ -1,9 +1,6 @@
-/* -*- mode: c; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ex: set tabstop=2 softtabstop=2 shiftwidth=2 expandtab: */
-
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2009,2011,2012, Intel Corporation.
+ * Copyright (C) 2009-2013 Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -15,7 +12,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 
+ * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
@@ -27,10 +24,10 @@
  * This enumeration type lists all supported storage controller types.
  */
 enum cntrl_type {
-  CNTRL_TYPE_UNKNOWN = 0,
-  CNTRL_TYPE_DELLSSD,
-  CNTRL_TYPE_SCSI,
-  CNTRL_TYPE_AHCI
+	CNTRL_TYPE_UNKNOWN = 0,
+	CNTRL_TYPE_DELLSSD,
+	CNTRL_TYPE_SCSI,
+	CNTRL_TYPE_AHCI
 };
 
 /**
@@ -39,47 +36,51 @@ enum cntrl_type {
  * This structure describes a storage controller device existing in the system.
  */
 struct cntrl_device {
-  /**
-   * Path to the device in sysfs tree.
-   */
-  char *sysfs_path;
+	/**
+	* Path to the device in sysfs tree.
+	*/
+	char *sysfs_path;
 
-  /**
-   * Type of storage controller device.
-   */
-  enum cntrl_type cntrl_type;
+	/**
+	 * Type of storage controller device.
+	 */
+	enum cntrl_type cntrl_type;
 
-  /**
-   * Flag if scsi controller driver is "isci"
-   */
-  int isci_present;
+	/**
+	 * Flag if scsi controller driver is "isci"
+	 */
+	int isci_present;
 
-  struct _host_type {
-    /**
-     * ibpi state buffer for directly attached devices
-     */
-    void *ibpi_state_buffer;
-    /**
-     * outbound raw byte stream
-     */
-    unsigned char bitstream[4];
-    /**
-     * host identifier for different hba instances
-     */
-    int host_id;
-    /**
-     * pointer to next structure
-     */
-    struct _host_type *next;
-  } *hosts;
+	struct _host_type {
+		/**
+		 * ibpi state buffer for directly attached devices
+		 */
+		void *ibpi_state_buffer;
+		/**
+		 * outbound raw byte stream
+		 */
+		unsigned char bitstream[4];
+		/**
+		 * bitstream's flush flag
+		 */
+		int flush;
+		/**
+		 * host identifier for different hba instances
+		 */
+		int host_id;
+		/**
+		 * pointer to next structure
+		 */
+		struct _host_type *next;
+	} *hosts;
 };
 
 /**
  * @brief Allocates a new controller device structure.
  *
  * This function allocates memory for a new structure of storage controller
- * device. It reads the sysfs entries and populates structure fields. The function
- * registers only supported storage controllers.
+ * device. It reads the sysfs entries and populates structure fields.
+ * The function registers only supported storage controllers.
  *
  * @param[in]      path           path to storage controller in sysfs tree.
  *
@@ -87,7 +88,7 @@ struct cntrl_device {
  *         function returns NULL pointer. The NULL pointer means that controller
  *         device is not supported.
  */
-struct cntrl_device * cntrl_device_init(const char *path);
+struct cntrl_device *cntrl_device_init(const char *path);
 
 /**
  * @brief Releases a controller device structure.
@@ -103,4 +104,4 @@ struct cntrl_device * cntrl_device_init(const char *path);
  */
 void cntrl_device_fini(struct cntrl_device *device);
 
-#endif /* _CNTRL_H_INCLUDED_ */
+#endif				/* _CNTRL_H_INCLUDED_ */
