@@ -1,9 +1,6 @@
-/* -*- mode: c; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ex: set tabstop=2 softtabstop=2 shiftwidth=2 expandtab: */
-
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2011,2012, Intel Corporation.
+ * Copyright (C) 2011-2013 Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -15,7 +12,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 
+ * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
@@ -38,6 +35,17 @@
  */
 int scsi_ses_write(struct block_device *device, enum ibpi_pattern ibpi);
 
+/**
+ * @brief Write message to outbound raw byte stream buffer.
+ *
+ * @param[in]      device         Path to a smp device in sysfs.
+ * @param[in]      ibpi           IBPI pattern to visualize.
+ *
+ * @return 1 if successful or -1 in case of error
+ *         and errno is set to appropriate error code.
+ */
+int scsi_smp_fill_buffer(struct block_device *device, enum ibpi_pattern ibpi);
+
 /**
  * @brief Sends message to SMP device.
  *
@@ -45,12 +53,11 @@ int scsi_ses_write(struct block_device *device, enum ibpi_pattern ibpi);
  * the given component.
  *
  * @param[in]      device         Path to a smp device in sysfs.
- * @param[in]      ibpi           IBPI pattern to visualize.
  *
  * @return Number of bytes written to device if successful or -1 in case of error
  *         and errno is set to appropriate error code.
  */
-int scsi_smp_write(struct block_device *device, enum ibpi_pattern ibpi);
+int scsi_smp_write_buffer(struct block_device *device);
 
 /**
  * @brief Init smp and gets phy index,
@@ -65,4 +72,4 @@ int scsi_smp_write(struct block_device *device, enum ibpi_pattern ibpi);
  */
 int isci_cntrl_init_smp(const char *path, struct cntrl_device *cntrl);
 
-#endif /* _SCSI_H_INCLUDED_ */
+#endif				/* _SCSI_H_INCLUDED_ */
